==> site_settings-8.x-1.0.tar.gz: site_settings/src/SiteSettingEntityListBuilder.php <==
<?php

namespace Drupal\site_settings;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Routing\LinkGeneratorTrait;
use Drupal\Core\Url;
use Drupal\site_settings\Entity\SiteSettingEntityType;
use Drupal\Core\Entity\EntityManager;

/**
 * Defines a class to build a listing of Site Setting entities.
 *
 * @ingroup site_settings
 */
class SiteSettingEntityListBuilder extends EntityListBuilder {

  use LinkGeneratorTrait;

  /**
   * Variable to store all bundles and be reduced by already set bundles.
   *
   * @var array
   */
  private $missingBundles = [];

  /**
   * Variable to store all bundles for quick access.
   *
   * @var array
   */
  private $bundles = [];

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['name'] = $this->t('Name');
    $header['fieldset'] = $this->t('Group');
    $header['value'] = $this->t('Value');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\site_settings\Entity\SiteSettingEntity */
    $row['name'] = $this->l(
      $entity->label(),
      new Url(
        'entity.site_setting_entity.edit_form', [
          'site_setting_entity' => $entity->id(),
        ]
      )
    );
    $entity_bundle = $entity->bundle();
    if ($bundle = SiteSettingEntityType::load($entity_bundle)) {
      $row['fieldset'] = $bundle->fieldset;
    }
    else {
      $row['fieldset'] = t('Unknown');
    }

    // Render the value of the field into the listing page.
    $row['value'] = '';
    $fields = $entity->getFields();
    foreach ($fields as $key => $field) {
      if (method_exists(get_class($field), 'getFieldDefinition')) {
        $row['value'] = ($row['value'] ? '<br />' : '');
        $row['value'] = $this->renderValue($field);
      }
    }

    return $row + parent::buildRow($entity);
  }

  /**
   * Render the value of the added fields.
   *
   * @param object $field
   *   The field to render.
   *
   * @return string
   *   The rendered html markup.
   */
  private function renderValue($field) {

    // Get information about the field.
    $definition = $field->getFieldDefinition();
    $field_type = $definition->getType();

    // Depending on the type of field, decide how to render.
    switch ($field_type) {
      case 'image':
        return $this->renderImage($field, $field_type);

      default:
        return $this->renderDefault($field, $field_type);

    }
  }

  /**
   * Render a very small version of the image.
   *
   * @param object $field
   *   The field to render.
   * @param object $field_type
   *   The field type to render.
   *
   * @return string
   *   The rendered html markup.
   */
  private function renderImage($field, $field_type) {
    $build = [
      '#theme' => 'image_style',
      '#width' => 25,
      '#height' => 25,
      '#style_name' => 'thumbnail',
      '#uri' => $field->entity->getFileUri(),
    ];
    return \Drupal::service('renderer')->render($build);
  }

  /**
   * Render a normal text value.
   *
   * @param object $field
   *   The field to render.
   * @param object $field_type
   *   The field type to render.
   *
   * @return string
   *   The rendered html markup.
   */
  private function renderDefault($field, $field_type) {
    $viewBuilder = \Drupal::entityTypeManager()->getViewBuilder('site_setting_entity');
    $build = $viewBuilder->viewField($field, [
      'type' => $field_type,
      'label' => 'hidden',
    ]);
    return \Drupal::service('renderer')->render($build);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEntityIds() {
    $query = $this->getStorage()->getQuery()
      ->sort($this->entityType->getKey('fieldset'))
      ->sort($this->entityType->getKey('id'));
    return $query->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function render() {

    $entity_type = $this->entityType->getBundleEntityType();
    $this->bundles = \Drupal::entityManager()->getStorage($entity_type)->loadMultiple();
    $this->missingBundles = array_keys($this->bundles);

    $site_settings = \Drupal::service('site_settings.loader');
    $variables['settings'] = $site_settings->loadAll(TRUE);

    $build['table'] = [
      '#type' => 'table',
      '#header' => $this->buildHeader(),
      '#title' => $this->getTitle(),
      '#rows' => [],
      '#empty' => $this->t('There is no @label yet.', ['@label' => $this->entityType->getLabel()]),
      '#cache' => [
        'contexts' => $this->entityType->getListCacheContexts(),
        'tags' => $this->entityType->getListCacheTags(),
      ],
    ];

    $last_fieldset = FALSE;
    foreach ($this->load() as $entity) {

      // Get bundle type.
      $bundle_type = $entity->getType();
      $search = array_search($bundle_type, $this->missingBundles);
      if ($search !== FALSE) {
        unset($this->missingBundles[$search]);
      }

      // Set fieldset separator.
      $fieldset = $entity->fieldset->getValue()[0]['value'];
      if ($fieldset != $last_fieldset) {
        $heading = [
          '#markup' => '<strong>' . $fieldset . '</strong>',
        ];
        $build['table']['#rows'][$fieldset] = [
          'name' => \Drupal::service('renderer')->render($heading),
          'fieldset' => '',
          'value' => '',
          'operations' => '',
        ];
        $last_fieldset = $fieldset;
      }

      // Add table rows.
      if ($row = $this->buildRow($entity)) {
        $build['table']['#rows'][$entity->id()] = $row;
      }
    }

    if ($this->missingBundles) {
      foreach ($this->missingBundles as $missing) {

        // Settings that have not yet been created rows.
        $url = new Url('entity.site_setting_entity.add_form', [
          'site_setting_entity_type' => $missing,
        ]);
        $link = [
          '#type' => 'link',
          '#title' => $this->t('Create setting'),
          '#url' => $url,
          '#attributes' => ['class' => ['button']],
        ];
        array_unshift($build['table']['#rows'], [
          'name' => $this->l($this->bundles[$missing]->label(), $url),
          'fieldset' => '',
          'value' => '',
          'operations' => \Drupal::service('renderer')->render($link),
        ]);

      }

      // Not yet created title.
      $heading = [
        '#markup' => '<strong>Settings not yet created</strong>',
      ];
      array_unshift($build['table']['#rows'], [
        'name' => \Drupal::service('renderer')->render($heading),
        'fieldset' => '',
        'value' => '',
        'operations' => '',
      ]);
    }

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOperations(EntityInterface $entity) {

    $build = [
      '#attributes' => ['class' => ['container-inline']],
    ];

    $operations = $this->getDefaultOperations($entity);
    $operations += $this->moduleHandler()->invokeAll('entity_operation', [$entity]);
    $this->moduleHandler->alter('entity_operation', $operations, $entity);

    uasort($operations, '\Drupal\Component\Utility\SortArray::sortByWeightElement');

    $build['operations'] = [
      '#prefix' => '<div class="align-left">',
      '#type' => 'operations',
      '#links' => $operations,
      '#suffix' => '</div>',
    ];

    // Add new operation.
    $entity_bundle = $entity->bundle();
    if (isset($this->bundles[$entity_bundle]) && $this->bundles[$entity_bundle]->multiple) {
      $url = new Url('entity.site_setting_entity.add_form', [
        'site_setting_entity_type' => $entity_bundle,
      ]);
      $build['add'] = [
        '#type' => 'link',
        '#title' => $this->t('Add another'),
        '#url' => $url,
        '#attributes' => ['class' => ['button']],
      ];

    }

    return $build;
  }

}

==> site_settings-8.x-1.9.tar.gz: site_settings/src/SiteSettingEntityListBuilder.php <==
<?php

namespace Drupal\site_settings;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Routing\LinkGeneratorTrait;
use Drupal\Core\Url;
use Drupal\site_settings\Entity\SiteSettingEntityType;

/**
 * Defines a class to build a listing of Site Setting entities.
 *
 * @ingroup site_settings
 */
class SiteSettingEntityListBuilder extends EntityListBuilder {

  use LinkGeneratorTrait;

  /**
   * Variable to store all bundles and be reduced by already set bundles.
   *
   * @var array
   */
  private $missingBundles = [];

  /**
   * Variable to store all bundles for quick access.
   *
   * @var array
   */
  private $bundles = [];

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['name'] = $this->t('Name');
    $header['fieldset'] = $this->t('Group');
    $header['value'] = $this->t('Value');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /* @var $entity \Drupal\site_settings\Entity\SiteSettingEntity */
    $row['name'] = $this->l(
      $entity->label(),
      new Url(
        'entity.site_setting_entity.edit_form', [
          'site_setting_entity' => $entity->id(),
        ]
      )
    );
    $entity_bundle = $entity->bundle();
    if ($bundle = SiteSettingEntityType::load($entity_bundle)) {
      $row['fieldset'] = $bundle->fieldset;
    }
    else {
      $row['fieldset'] = t('Unknown');
    }

    // Render the value of the field into the listing page.
    $row['value'] = '';
    $fields = $entity->getFields();
    $site_settings_renderer = \Drupal::service('site_settings.renderer');
    foreach ($fields as $key => $field) {
      if (method_exists(get_class($field), 'getFieldDefinition')) {
        $row['value'] = ($row['value'] ? '<br />' : '');
        $row['value'] = $site_settings_renderer->renderField($field);
      }
    }

    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEntityIds() {
    $query = $this->getStorage()->getQuery()
      ->sort($this->entityType->getKey('fieldset'))
      ->sort($this->entityType->getKey('id'));
    return $query->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function render() {

    $entity_type = $this->entityType->getBundleEntityType();
    $this->bundles = \Drupal::entityTypeManager()
      ->getStorage($entity_type)
      ->loadMultiple();
    $this->missingBundles = array_keys($this->bundles);

    $site_settings = \Drupal::service('site_settings.loader');
    $variables['settings'] = $site_settings->loadAll(TRUE);

    $build['table'] = [
      '#type' => 'table',
      '#header' => $this->buildHeader(),
      '#title' => $this->getTitle(),
      '#rows' => [],
      '#empty' => $this->t('There is no @label yet.', ['@label' => $this->entityType->getLabel()]),
      '#cache' => [
        'contexts' => $this->entityType->getListCacheContexts(),
        'tags' => $this->entityType->getListCacheTags(),
      ],
    ];

    $last_fieldset = FALSE;
    foreach ($this->load() as $entity) {

      // Get bundle type.
      $bundle_type = $entity->getType();
      $search = array_search($bundle_type, $this->missingBundles);
      if ($search !== FALSE) {
        unset($this->missingBundles[$search]);
      }

      // Set fieldset separator.
      $fieldset = $entity->fieldset->getValue()[0]['value'];
      if ($fieldset != $last_fieldset) {
        $heading = [
          '#markup' => '<strong>' . $fieldset . '</strong>',
        ];
        $build['table']['#rows'][$fieldset] = [
          'name' => \Drupal::service('renderer')->render($heading),
          'fieldset' => '',
          'value' => '',
          'operations' => '',
        ];
        $last_fieldset = $fieldset;
      }

      // Add table rows.
      if ($row = $this->buildRow($entity)) {
        $build['table']['#rows'][$entity->id()] = $row;
      }
    }

    if ($this->missingBundles) {
      foreach ($this->missingBundles as $missing) {

        // Settings that have not yet been created rows.
        $url = new Url('entity.site_setting_entity.add_form', [
          'site_setting_entity_type' => $missing,
        ]);
        $link = [
          '#type' => 'link',
          '#title' => $this->t('Create setting'),
          '#url' => $url,
          '#attributes' => ['class' => ['button']],
        ];
        array_unshift($build['table']['#rows'], [
          'name' => $this->l($this->bundles[$missing]->label(), $url),
          'fieldset' => '',
          'value' => '',
          'operations' => \Drupal::service('renderer')->render($link),
        ]);

      }

      // Not yet created title.
      $heading = [
        '#markup' => '<strong>Settings not yet created</strong>',
      ];
      array_unshift($build['table']['#rows'], [
        'name' => \Drupal::service('renderer')->render($heading),
        'fieldset' => '',
        'value' => '',
        'operations' => '',
      ]);
    }

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOperations(EntityInterface $entity) {

    $build = [
      '#attributes' => ['class' => ['container-inline']],
    ];

    $operations = $this->getDefaultOperations($entity);
    $operations += $this->moduleHandler()->invokeAll('entity_operation', [$entity]);
    $this->moduleHandler->alter('entity_operation', $operations, $entity);

    uasort($operations, '\Drupal\Component\Utility\SortArray::sortByWeightElement');

    $build['operations'] = [
      '#prefix' => '<div class="align-left">',
      '#type' => 'operations',
      '#links' => $operations,
      '#suffix' => '</div>',
    ];

    // Add new operation.
    $entity_bundle = $entity->bundle();
    if (isset($this->bundles[$entity_bundle]) && $this->bundles[$entity_bundle]->multiple) {
      $url = new Url('entity.site_setting_entity.add_form', [
        'site_setting_entity_type' => $entity_bundle,
      ]);
      $build['add'] = [
        '#type' => 'link',
        '#title' => $this->t('Add another'),
        '#url' => $url,
        '#attributes' => ['class' => ['button']],
      ];

    }

    return $build;
  }

}
